@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda::Config;
-$Qgoda::Config::VERSION = '0.9.6';
+$Qgoda::Config::VERSION = '0.9.7';
 use strict;
 
 use Locale::TextDomain qw('qgoda');
@@ -104,14 +104,14 @@ sub new {
 	if ($invalid) {
 		my ($filename, $errors) = @$invalid;
 		my $msg = '';
-		if (ref $errors) {
+		if (ref $errors && 'ARRAY' eq ref $errors) {
 			foreach my $error (@$errors) {
 				$msg .= __x("{filename}: CONFIG{dataPath}: ",
 				             filename => $filename,
 							 dataPath => $error->{dataPath});
 				$msg .= "$error->{message}\n";
 				my $params = $error->{params};
-				foreach my $param (keys %$params) {
+				foreach my $param (keys %{$params || {}}) {
 					$msg .= "\t$param: $params->{$param}\n";
 				}
 			}
